@@ -24,8 +24,10 @@ pub mod flow {
 
 // for signing transactions
 use bytes::Bytes;
-use p256_flow::ecdsa::{signature_flow::Signature, signature_flow::Signer, SigningKey};
+pub use p256_flow::ecdsa::SigningKey;
+use p256_flow::ecdsa::{signature_flow::Signature, signature_flow::Signer};
 use p256_flow::elliptic_curve_flow::SecretKey;
+pub use rand_core::OsRng;
 pub extern crate hex;
 pub extern crate rlp;
 use rlp::*;
